@@ -1,4 +1,4 @@
-# Copyright 2009-2017, Damian Johnson and The Tor Project
+# Copyright 2009-2019, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -43,7 +43,7 @@ Tor curses monitoring application.
 """
 
 import contextlib
-import distutils.spawn
+import getpass
 import os
 import platform
 import sys
@@ -75,7 +75,7 @@ SQLITE_UNAVAILABLE_FREEBSD = """\
 Python's sqlite3 module is unavailable. Please run...
 
   sudo pkg install py%i%i-sqlite3
-""" % (sys.version_info[:2])
+""" % sys.version_info[:2]
 
 try:
   import sqlite3
@@ -89,8 +89,8 @@ except ImportError:
 
   sys.exit(1)
 
-__version__ = '2.0.4'
-__release_date__ = 'November 5, 2017'
+__version__ = '2.1.0'
+__release_date__ = 'January 12, 2019'
 __author__ = 'Damian Johnson'
 __contact__ = 'atagar@torproject.org'
 __url__ = 'https://nyx.torproject.org/'
@@ -176,9 +176,9 @@ def main():
     nyx.starter.main()
   except ImportError as exc:
     if exc.message == 'No module named stem':
-      if distutils.spawn.find_executable('pip') is not None:
+      if stem.util.system.is_available('pip'):
         advice = ", try running 'sudo pip install stem'"
-      elif distutils.spawn.find_executable('apt-get') is not None:
+      elif stem.util.system.is_available('apt-get'):
         advice = ", try running 'sudo apt-get install python-stem'"
       else:
         advice = ', you can find it at https://stem.torproject.org/download.html'
@@ -337,9 +337,10 @@ def data_directory(filename, config):
 
   if not os.path.exists(data_dir):
     try:
-      os.mkdir(data_dir)
+      os.makedirs(data_dir)
     except OSError as exc:
-      stem.util.log.log_once('nyx.data_directory_unavailable', stem.util.log.NOTICE, 'Unable to create a data directory at %s (%s). This is fine, but caching is disabled meaning performance will be diminished a bit.' % (data_dir, exc))
+      msg_runlevel = stem.util.log.INFO if 'Permission denied' in str(exc) else stem.util.log.NOTICE
+      stem.util.log.log_once('nyx.data_directory_unavailable', msg_runlevel, 'Unable to create a data directory at %s (%s). This is fine, but caching is disabled meaning performance will be diminished a bit.' % (data_dir, exc))
       return None
 
   return os.path.join(data_dir, filename)
@@ -441,10 +442,14 @@ class Cache(object):
     self._conn_lock = threading.RLock()
     cache_path = nyx.data_directory('cache.sqlite')
 
+    if cache_path and os.path.isfile(cache_path) and not os.access(cache_path, os.W_OK):
+      stem.util.log.notice("Nyx's cache at %s is not writable by our user (%s). That's ok, but we'll have better performance if we can write to it." % (cache_path, getpass.getuser()))
+      cache_path = None
+
     if cache_path:
       try:
         self._conn = sqlite3.connect(cache_path, check_same_thread = False)
-        schema = self._conn.execute('SELECT version FROM schema').fetchone()[0]
+        schema = self._query('SELECT version FROM schema').fetchone()[0]
       except:
         schema = None
 
